@@ -21,6 +21,10 @@ import cachetclient.exceptions as exceptions
 
 @decorator
 def api_token_required(f, *args, **kwargs):
+    """
+    Decorator helper function to ensure some methods aren't needlessly called
+    without an api_token configured.
+    """
     try:
         if args[0].api_token is None:
             raise AttributeError('Parameter api_token is required.')
@@ -31,15 +35,22 @@ def api_token_required(f, *args, **kwargs):
 
 
 def check_required_args(required_args, args):
+    """
+    Checks if all required_args have a value.
+    :param required_args: list of required args
+    :param args: kwargs
+    :return: True (if an exception isn't raised)
+    """
     for arg in required_args:
         if arg not in args:
             raise KeyError('Required argument: %s' % arg)
+    return True
 
 
 class Cachet(client.CachetClient):
     """
-    Wrapper library around the available API calls for the admin.ci.centos.org
-    node infrastructure.
+    Base class that extends CachetClient and defaults API methods to
+    unimplemented.
     """
     def __init__(self, **kwargs):
         super(Cachet, self).__init__(**kwargs)
@@ -59,30 +70,52 @@ class Cachet(client.CachetClient):
 
 
 class Ping(Cachet):
+    """
+    /ping API endpoint
+    """
     def __init__(self, **kwargs):
         super(Ping, self).__init__(**kwargs)
 
     def get(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/ping
+        """
         return self._get('ping')
 
 
 class Version(Cachet):
+    """
+    /version API endpoint
+    """
     def __init__(self, **kwargs):
         super(Version, self).__init__(**kwargs)
 
     def get(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/version
+        """
         return self._get('version')
 
 
 class Components(Cachet):
+    """
+    /components API endpoint
+    """
     def __init__(self, **kwargs):
         super(Components, self).__init__(**kwargs)
 
     @api_token_required
     def delete(self, id):
+        """
+        https://docs.cachethq.io/docs/delete-a-component
+        """
         return self._delete('components/%s' % id)
 
     def get(self, id=None, **kwargs):
+        """
+        https://docs.cachethq.io/docs/get-components
+        https://docs.cachethq.io/docs/get-a-component
+        """
         if id is not None:
             return self._get('components/%s' % id)
         else:
@@ -90,6 +123,9 @@ class Components(Cachet):
 
     @api_token_required
     def post(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/components
+        """
         # default values
         kwargs.setdefault('enabled', kwargs.get('enabled', True))
 
@@ -100,6 +136,9 @@ class Components(Cachet):
 
     @api_token_required
     def put(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/update-a-component
+        """
         required_args = ['id']
         check_required_args(required_args, kwargs)
 
@@ -107,14 +146,24 @@ class Components(Cachet):
 
 
 class Groups(Cachet):
+    """
+    /components/groups API endpoint
+    """
     def __init__(self, **kwargs):
         super(Groups, self).__init__(**kwargs)
 
     @api_token_required
     def delete(self, id):
+        """
+        https://docs.cachethq.io/docs/delete-component-group
+        """
         return self._delete('components/groups/%s' % id)
 
     def get(self, id=None, **kwargs):
+        """
+        https://docs.cachethq.io/docs/get-componentgroups
+        https://docs.cachethq.io/docs/get-a-component-group
+        """
         if id is not None:
             return self._get('components/groups/%s' % id, data=kwargs)
         else:
@@ -122,6 +171,9 @@ class Groups(Cachet):
 
     @api_token_required
     def post(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/post-componentgroups
+        """
         required_args = ['name']
         check_required_args(required_args, kwargs)
 
@@ -129,6 +181,9 @@ class Groups(Cachet):
 
     @api_token_required
     def put(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/put-component-group
+        """
         required_args = ['id']
         check_required_args(required_args, kwargs)
 
@@ -136,14 +191,24 @@ class Groups(Cachet):
 
 
 class Incidents(Cachet):
+    """
+    /incidents API endpoint
+    """
     def __init__(self, **kwargs):
         super(Incidents, self).__init__(**kwargs)
 
     @api_token_required
     def delete(self, id):
+        """
+        https://docs.cachethq.io/docs/delete-an-incident
+        """
         return self._delete('incidents/%s' % id)
 
     def get(self, id=None, **kwargs):
+        """
+        https://docs.cachethq.io/docs/get-incidents
+        https://docs.cachethq.io/docs/get-an-incident
+        """
         if id is not None:
             return self._get('incidents/%s' % id, data=kwargs)
         else:
@@ -151,6 +216,9 @@ class Incidents(Cachet):
 
     @api_token_required
     def post(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/incidents
+        """
         # default values
         kwargs.setdefault('visible', kwargs.get('visible', True))
         kwargs.setdefault('notify', kwargs.get('notify', False))
@@ -162,6 +230,9 @@ class Incidents(Cachet):
 
     @api_token_required
     def put(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/update-an-incident
+        """
         required_args = ['id']
         check_required_args(required_args, kwargs)
 
@@ -169,14 +240,24 @@ class Incidents(Cachet):
 
 
 class Metrics(Cachet):
+    """
+    /metrics API endpoint
+    """
     def __init__(self, **kwargs):
         super(Metrics, self).__init__(**kwargs)
 
     @api_token_required
     def delete(self, id):
+        """
+        https://docs.cachethq.io/docs/delete-a-metric
+        """
         return self._delete('metrics/%s' % id)
 
     def get(self, id=None, **kwargs):
+        """
+        https://docs.cachethq.io/docs/get-metrics
+        https://docs.cachethq.io/docs/get-a-metric
+        """
         if id is not None:
             return self._get('metrics/%s' % id, data=kwargs)
         else:
@@ -184,6 +265,9 @@ class Metrics(Cachet):
 
     @api_token_required
     def post(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/metrics
+        """
         # default values
         kwargs.setdefault('default_value', kwargs.get('default_value', 0))
 
@@ -194,14 +278,23 @@ class Metrics(Cachet):
 
 
 class Points(Cachet):
+    """
+    /metrics/<metric>/points API endpoint
+    """
     def __init__(self, **kwargs):
         super(Points, self).__init__(**kwargs)
 
     @api_token_required
     def delete(self, metric_id, point_id):
+        """
+        https://docs.cachethq.io/docs/delete-a-metric-point
+        """
         return self._delete('metrics/%s/points/%s' % (metric_id, point_id))
 
     def get(self, metric_id=None, **kwargs):
+        """
+        https://docs.cachethq.io/docs/get-metric-points
+        """
         if metric_id is None:
             raise AttributeError('metric_id is required to get metric points.')
 
@@ -209,6 +302,9 @@ class Points(Cachet):
 
     @api_token_required
     def post(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/post-metric-points
+        """
         required_args = ['id', 'value']
         check_required_args(required_args, kwargs)
 
@@ -216,18 +312,30 @@ class Points(Cachet):
 
 
 class Subscribers(Cachet):
+    """
+    /subscribers API endpoint
+    """
     def __init__(self, **kwargs):
         super(Subscribers, self).__init__(**kwargs)
 
     @api_token_required
     def delete(self, id):
+        """
+        https://docs.cachethq.io/docs/delete-subscriber
+        """
         return self._delete('subscribers/%s' % id)
 
     def get(self, **kwargs):
-            return self._get('subscribers', data=kwargs)
+        """
+        https://docs.cachethq.io/docs/get-subscribers
+        """
+        return self._get('subscribers', data=kwargs)
 
     @api_token_required
     def post(self, **kwargs):
+        """
+        https://docs.cachethq.io/docs/subscribers
+        """
         required_args = ['email']
         check_required_args(required_args, kwargs)
 
